pub fn sanitize(route: &str) -> Result<PathBuf, DangerousPathError>Expand description
URL-decodes and converts request route into a relative path and checks its safety.
See DangerousPathError for details of these checks
pub fn sanitize(route: &str) -> Result<PathBuf, DangerousPathError>URL-decodes and converts request route into a relative path and checks its safety.
See DangerousPathError for details of these checks